@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 import os
 
 __author__ = 'Morgan Hargrove'
