@@ -13,7 +13,7 @@ import os
 import random
 import time
 import traceback
-from collections import OrderedDict
+from collections import OrderedDict, defaultdict
 
 from pymongo.mongo_client import MongoClient
 from pymongo import DESCENDING, ASCENDING
@@ -231,6 +231,7 @@ class LaunchPad(FWSerializable):
         # prefer to wf.refresh() for speed reasons w/many root FWs
         for fw_id in wf.root_fw_ids:
             wf.id_fw[fw_id].state = 'READY'
+            wf.fw_states[fw_id] = 'READY'
 
         # insert the FireWorks and get back mapping of old to new ids
         old_new = self._upsert_fws(list(wf.id_fw.values()), reassign_all=reassign_all)
@@ -353,6 +354,7 @@ class LaunchPad(FWSerializable):
         if mode != "less":
             wf_fields.append("updated_on")
             fw_fields.extend(["name", "launches"])
+            launch_fields.append("launch_id")
             launch_fields.append("launch_dir")
 
         if mode == "reservations":
@@ -364,15 +366,25 @@ class LaunchPad(FWSerializable):
         wf = self.workflows.find_one({"nodes": fw_id}, fields=wf_fields)
         fw_data = []
         id_name_map = {}
+        launch_ids = []
         for fw in self.fireworks.find({"fw_id": {"$in": wf["nodes"]}},
                                       fields=fw_fields):
             if launch_fields:
-                fw["launches"] = list(
-                    self.launches.find({'launch_id': {"$in": fw['launches']}},
-                                       fields=launch_fields))
+                launch_ids.extend(fw["launches"])
             fw_data.append(fw)
             if mode != "less":
                 id_name_map[fw["fw_id"]] = "%s--%d" % (fw["name"], fw["fw_id"])
+
+        if launch_fields:
+            launch_info = defaultdict(list)
+            for l in self.launches.find({'launch_id': {"$in": launch_ids}},
+                                        fields=launch_fields):
+                for i, fw in enumerate(fw_data):
+                    if l["launch_id"] in fw["launches"]:
+                        launch_info[i].append(l)
+            for k, v in launch_info.items():
+                fw_data[k]["launches"] = v
+
         wf["fw"] = fw_data
 
         # Post process the summary dict so that it "looks" better.
@@ -775,6 +787,7 @@ class LaunchPad(FWSerializable):
 
         m_fw.state = 'RUNNING'
         self._upsert_fws([m_fw])
+        self._refresh_wf(m_fw.fw_id)
 
         # update any duplicated runs
         for fw in self.fireworks.find(
@@ -784,6 +797,7 @@ class LaunchPad(FWSerializable):
             fw = self.get_fw_by_id(fw_id)
             fw.state = 'RUNNING'
             self._upsert_fws([fw])
+            self._refresh_wf(fw.fw_id)
 
         self.m_logger.debug('Checked out FW with id: {}'.format(m_fw.fw_id))
 
@@ -1168,4 +1182,4 @@ class LazyFirework(object):
                 result = []
             setattr(fw, name, result)  # put into real FireWork obj
             self._launches[name] = True
-        return getattr(fw, name)
\ No newline at end of file
+        return getattr(fw, name)
