@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 import os
 from fireworks.queue.queue_adapter import QueueAdapterBase
 import getpass
@@ -13,8 +17,8 @@ __date__ = 'Nov 21, 2013'
 
 class PBSAdapterNEWT(QueueAdapterBase):
     """
-    A PBS adapter that works via the NEWT interface (https://newt.nersc.gov)
-    Seems to only work on Carver at the moment (hard-coded)
+    A special PBS adapter that works via the NEWT interface (https://newt.nersc.gov)
+    Only intended for job submission via the RESTful NEWT web interface.
     """
     _fw_name = 'PBSAdapter (NEWT)'
     template_file = os.path.join(os.path.dirname(__file__), 'PBS_template.txt')
@@ -59,4 +63,4 @@ class PBSAdapterNEWT(QueueAdapterBase):
             if r.json()['auth'] and r.json()['username'] == username:
                 return
             pw_iterations += 1
-        raise ValueError('Could not get authorized connection to NEWT!')
\ No newline at end of file
+        raise ValueError('Could not get authorized connection to NEWT!')
